Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6056)

Unified Diff: chrome/browser/ui/views/payments/editor_view_controller.cc

Issue 2859193004: Remove GridLayout::SetInsets in favor of an empty border on the host. (Closed)
Patch Set: missed a merge problem Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/editor_view_controller.cc
diff --git a/chrome/browser/ui/views/payments/editor_view_controller.cc b/chrome/browser/ui/views/payments/editor_view_controller.cc
index fa3ab44d70d1f4f7a61a4486a79ad16f0829fdcd..1c349b3e7eec5357cd8585085d1988083940efdf 100644
--- a/chrome/browser/ui/views/payments/editor_view_controller.cc
+++ b/chrome/browser/ui/views/payments/editor_view_controller.cc
@@ -186,9 +186,10 @@ std::unique_ptr<views::View> EditorViewController::CreateEditorView() {
std::unique_ptr<views::GridLayout> editor_layout =
base::MakeUnique<views::GridLayout>(editor_view.get());
- // The editor grid layout is padded horizontally.
- editor_layout->SetInsets(0, payments::kPaymentRequestRowHorizontalInsets, 0,
- payments::kPaymentRequestRowHorizontalInsets);
+ // The editor view is padded horizontally.
+ editor_view->SetBorder(views::CreateEmptyBorder(
+ 0, payments::kPaymentRequestRowHorizontalInsets, 0,
+ payments::kPaymentRequestRowHorizontalInsets));
views::ColumnSet* columns = editor_layout->AddColumnSet(0);
columns->AddColumn(views::GridLayout::LEADING, views::GridLayout::CENTER, 0,

Powered by Google App Engine
This is Rietveld 408576698